@@ -3,37 +3,20 @@ import sys
 from enum import Enum, auto
 from tempfile import gettempdir
 
-from numpy.ma import masked as numpy_ma_masked
+import numpy as np
+from dask import config
+from dask.utils import parse_bytes
 from psutil import virtual_memory
 
-from . import mpi_on, mpi_size
-
-if mpi_on:
-    from . import mpi_comm
-
 from .units import Units
 
-# platform = sys.platform
-# if platform == 'darwin':
-#     from psutil import virtual_memory
-
 # --------------------------------------------------------------------
 # Find the total amount of memory, in bytes
 # --------------------------------------------------------------------
 _TOTAL_MEMORY = float(virtual_memory().total)
-# if platform == 'darwin':
-#     # MacOS
-#    _MemTotal = float(virtual_memory().total)
-# else:
-#     # Linux
-#     _meminfo_file = open('/proc/meminfo', 'r', 1)
-#     for line in _meminfo_file:
-#         field_size = line.split()
-#         if field_size[0] == 'MemTotal:':
-#             _MemTotal = float(field_size[1]) * 1024
-#             break
-#
-#     _meminfo_file.close()
+
+_CHUNKSIZE = "128 MiB"
+config.set({"array.chunk-size": _CHUNKSIZE})
 
 
 """A dictionary of useful constants.
@@ -53,41 +36,18 @@ in cf.
     TOTAL_MEMORY: `float`
       Find the total amount of physical memory (in bytes).
 
-    CHUNKSIZE: `float`
+    CHUNKSIZE: `int`
       The chunk size (in bytes) for data storage and processing.
 
-    FM_THRESHOLD: `float`
-      The minimum amount of memory (in bytes) to be kept free for
-      temporary work space. This should always be MINNCFM*CHUNKSIZE.
-
-    MINNCFM: `int`
-      The number of chunk sizes to be kept free for temporary work
-      space.
-
-    OF_FRACTION: `float`
-      The fraction of the maximum number of concurrently open files
-      which may be used for files containing data arrays.
-
     TEMPDIR: `str`
       The location to store temporary files. By default it is the
       default directory used by the :mod:`tempfile` module.
 
     REGRID_LOGGING: `bool`
-      Whether or not to enable `ESMF` logging. If it is logging is
-      performed after every call to `ESMF`. By default logging is
+      Whether or not to enable `esmpy` logging. If it is logging is
+      performed after every call to `esmpy`. By default logging is
       disabled.
 
-    FREE_MEMORY_FACTOR: `int`
-      Factor to divide the free memory by. If MPI is on this is equal
-      to the number of PEs. Otherwise it is equal to 1 and is ignored
-      in any case.
-
-    COLLAPSE_PARALLEL_MODE: `int`
-      The mode to use when parallelising collapse. By default this is
-      0 to try and automatically determine which mode to use.
-
-      Deprecated at version 3.9.0
-
     LOG_LEVEL: `str`
       The minimal level of seriousness for which log messages are
       shown. See `cf.log_level`.
@@ -97,44 +57,19 @@ CONSTANTS = {
     "ATOL": sys.float_info.epsilon,
     "RTOL": sys.float_info.epsilon,
     "TEMPDIR": gettempdir(),
-    "OF_FRACTION": 0.5,
     "TOTAL_MEMORY": _TOTAL_MEMORY,
-    "FREE_MEMORY_FACTOR": 0.1,
-    "WORKSPACE_FACTOR_1": 2.0,
-    "WORKSPACE_FACTOR_2": 8.0,
     "REGRID_LOGGING": False,
-    "COLLAPSE_PARALLEL_MODE": 0,
     "RELAXED_IDENTITIES": False,
     "LOG_LEVEL": logging.getLevelName(logging.getLogger().level),
     "BOUNDS_COMBINATION_MODE": "AND",
+    "CHUNKSIZE": parse_bytes(_CHUNKSIZE),
 }
 
-CONSTANTS["FM_THRESHOLD"] = (
-    CONSTANTS["FREE_MEMORY_FACTOR"] * CONSTANTS["TOTAL_MEMORY"]
-)
-
-if mpi_on:
-    CONSTANTS["MIN_TOTAL_MEMORY"] = min(
-        mpi_comm.allgather(CONSTANTS["TOTAL_MEMORY"])
-    )
-else:
-    CONSTANTS["MIN_TOTAL_MEMORY"] = CONSTANTS["TOTAL_MEMORY"]
-
-CONSTANTS["CHUNKSIZE"] = (
-    CONSTANTS["FREE_MEMORY_FACTOR"] * CONSTANTS["MIN_TOTAL_MEMORY"]
-) / (
-    mpi_size * CONSTANTS["WORKSPACE_FACTOR_1"]
-    + CONSTANTS["WORKSPACE_FACTOR_2"]
-)
-
-masked = numpy_ma_masked
-# nomask = numpy_ma_nomask
+masked = np.ma.masked
 
 repr_prefix = "CF "
 repr_suffix = ""
 
-_file_to_fh = {}
-
 _stash2standard_name = {}
 
 # ---------------------------------------------------------------------
@@ -537,32 +472,20 @@ formula_terms_computed_standard_names = {
         "orog": {
             "surface_altitude": "altitude",
             "surface_height_above_geopotential_datum": "height_above_geopotential_datum",
-        },
+        }
     },
     "atmosphere_sleve_coordinate": {
         "ztop": {
             "altitude_at_top_of_atmosphere_model": "altitude",
             "height_above_geopotential_datum_at_top_of_atmosphere_model": "height_above_geopotential_datum",
-        },
-    },
-    "ocean_sigma_coordinate": {
-        "depth": _D1_depth_mapping,
-    },
-    "ocean_s_coordinate": {
-        "depth": _D1_depth_mapping,
-    },
-    "ocean_s_coordinate_g1": {
-        "depth": _D1_depth_mapping,
-    },
-    "ocean_s_coordinate_g2": {
-        "depth": _D1_depth_mapping,
-    },
-    "ocean_sigma_z_coordinate": {
-        "depth": _D1_depth_mapping,
-    },
-    "ocean_double_sigma_coordinate": {
-        "depth": _D1_depth_mapping,
+        }
     },
+    "ocean_sigma_coordinate": {"depth": _D1_depth_mapping},
+    "ocean_s_coordinate": {"depth": _D1_depth_mapping},
+    "ocean_s_coordinate_g1": {"depth": _D1_depth_mapping},
+    "ocean_s_coordinate_g2": {"depth": _D1_depth_mapping},
+    "ocean_sigma_z_coordinate": {"depth": _D1_depth_mapping},
+    "ocean_double_sigma_coordinate": {"depth": _D1_depth_mapping},
 }
 
 # --------------------------------------------------------------------
@@ -570,15 +493,8 @@ formula_terms_computed_standard_names = {
 # Appendix D: Parametric Vertical Coordinates of the CF conventions.
 # --------------------------------------------------------------------
 formula_terms_units = {
-    "atmosphere_ln_pressure_coordinate": {
-        "p0": "Pa",
-        "lev": "",
-    },
-    "atmosphere_sigma_coordinate": {
-        "sigma": "",
-        "ptop": "Pa",
-        "ps": "Pa",
-    },
+    "atmosphere_ln_pressure_coordinate": {"p0": "Pa", "lev": ""},
+    "atmosphere_sigma_coordinate": {"sigma": "", "ptop": "Pa", "ps": "Pa"},
     "atmosphere_hybrid_sigma_pressure_coordinate": {
         "p0": "Pa",
         "ps": "Pa",
@@ -586,11 +502,7 @@ formula_terms_units = {
         "a": "",
         "b": "",
     },
-    "atmosphere_hybrid_height_coordinate": {
-        "a": "m",
-        "b": "",
-        "orog": "m",
-    },
+    "atmosphere_hybrid_height_coordinate": {"a": "m", "b": "", "orog": "m"},
     "atmosphere_sleve_coordinate": {
         "ztop": "m",
         "a": "",
@@ -599,11 +511,7 @@ formula_terms_units = {
         "zsurf1": "m",
         "zsurf2": "m",
     },
-    "ocean_sigma_coordinate": {
-        "eta": "m",
-        "depth": "m",
-        "sigma": "",
-    },
+    "ocean_sigma_coordinate": {"eta": "m", "depth": "m", "sigma": ""},
     "ocean_s_coordinate": {
         "eta": "m",
         "depth": "m",
