@@ -1,8 +1,6 @@
 import cfdm
 
-from . import Bounds
-
-from . import mixin
+from . import Bounds, mixin
 
 
 class DomainAncillary(mixin.PropertiesDataBounds, cfdm.DomainAncillary):
@@ -30,15 +28,7 @@ class DomainAncillary(mixin.PropertiesDataBounds, cfdm.DomainAncillary):
     """
 
     def __new__(cls, *args, **kwargs):
-        """TODO."""
+        """Store component classes."""
         instance = super().__new__(cls)
         instance._Bounds = Bounds
         return instance
-
-    def __repr__(self):
-        """Called by the `repr` built-in function.
-
-        x.__repr__() <==> repr(x)
-
-        """
-        return super().__repr__().replace("<", "<CF ", 1)
