@@ -1,6 +1,6 @@
 """This class is not in the cf.mixin package because it needs to be
 imported by cf.Data, and some of the other mixin classes in cf.mixin
-themsleves import cf.Data, which would lead to a circular import
+themselves import cf.Data, which would lead to a circular import
 situation.
 
 """
@@ -14,6 +14,16 @@ class Container:
 
     """
 
+    def __repr__(self):
+        """Called by the `repr` built-in function.
+
+        x.__repr__() <==> repr(x)
+
+        .. versionadded:: 3.16.0
+
+        """
+        return super().__repr__().replace("<", "<CF ", 1)
+
     def __docstring_substitutions__(self):
         """Define docstring substitutions that apply to this class and
         all of its subclasses.
